@@ -265,6 +265,9 @@ moblin_netbook_draw_box (GtkStyle     *style,
 
       /* always draw button as shadow out to match the entry */
       shadow_type = GTK_SHADOW_OUT;
+
+      /* draw the buttons with the same state type as the entry */
+      state_type = widget->state;
     }
 
   /*** combo boxes ***/
@@ -326,7 +329,7 @@ moblin_netbook_draw_box (GtkStyle     *style,
   /* scrollbar slider */
   if (DETAIL ("slider"))
     {
-      if (width > height)
+      if (widget && GTK_IS_HSCROLLBAR (widget))
         {
           y += 2;
           height -= 4;
@@ -482,6 +485,14 @@ moblin_netbook_draw_shadow (GtkStyle     *style,
       button = g_object_get_data (G_OBJECT (widget->parent),
                                   "moblin-netbook-combo-button");
 
+
+      if (GTK_WIDGET_HAS_FOCUS (button))
+        state_type = GTK_STATE_PRELIGHT;
+      else
+        /* try and keep the button and entry in the same state */
+        gtk_widget_set_state (button, state_type);
+
+
       width += 10;
     }
 
